package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickSilentStepperActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Set Max Velocity")
    public void setMaxVelocity(
            @ActionInput(name = "velocity") int velocity) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setMaxVelocity(velocity);
    }

    public static void setMaxVelocity(@Nullable ThingActions actions, int velocity) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setMaxVelocity(velocity);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Max Velocity")
    public @ActionOutput(name = "velocity", type="int")
           Map<String, Object> getMaxVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getMaxVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getMaxVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getMaxVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Current Velocity")
    public @ActionOutput(name = "velocity", type="int")
           Map<String, Object> getCurrentVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getCurrentVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getCurrentVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getCurrentVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Speed Ramping")
    public void setSpeedRamping(
            @ActionInput(name = "acceleration") int acceleration,
            @ActionInput(name = "deacceleration") int deacceleration) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setSpeedRamping(acceleration, deacceleration);
    }

    public static void setSpeedRamping(@Nullable ThingActions actions, int acceleration, int deacceleration) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setSpeedRamping(acceleration, deacceleration);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Speed Ramping")
    public @ActionOutput(name = "acceleration", type="int")
           @ActionOutput(name = "deacceleration", type="int")
           Map<String, Object> getSpeedRamping(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.SpeedRamping value = ((BrickSilentStepper)this.handler.getDevice()).getSpeedRamping();
        result.put("acceleration", value.acceleration);
        result.put("deacceleration", value.deacceleration);
        return result;
    }

    public static Map<String, Object> getSpeedRamping(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getSpeedRamping();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Full Brake")
    public void fullBrake(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).fullBrake();
    }

    public static void fullBrake(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).fullBrake();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Steps")
    public void setSteps(
            @ActionInput(name = "steps") int steps) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setSteps(steps);
    }

    public static void setSteps(@Nullable ThingActions actions, int steps) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setSteps(steps);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Steps")
    public @ActionOutput(name = "steps", type="int")
           Map<String, Object> getSteps(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getSteps();
        result.put("steps", value);
        return result;
    }

    public static Map<String, Object> getSteps(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getSteps();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Remaining Steps")
    public @ActionOutput(name = "steps", type="int")
           Map<String, Object> getRemainingSteps(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getRemainingSteps();
        result.put("steps", value);
        return result;
    }

    public static Map<String, Object> getRemainingSteps(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getRemainingSteps();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Drive Forward")
    public void driveForward(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).driveForward();
    }

    public static void driveForward(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).driveForward();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Drive Backward")
    public void driveBackward(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).driveBackward();
    }

    public static void driveBackward(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).driveBackward();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Stop")
    public void stop(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).stop();
    }

    public static void stop(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).stop();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Motor Current")
    public void setMotorCurrent(
            @ActionInput(name = "current") int current) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setMotorCurrent(current);
    }

    public static void setMotorCurrent(@Nullable ThingActions actions, int current) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setMotorCurrent(current);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Motor Current")
    public @ActionOutput(name = "current", type="int")
           Map<String, Object> getMotorCurrent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getMotorCurrent();
        result.put("current", value);
        return result;
    }

    public static Map<String, Object> getMotorCurrent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getMotorCurrent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Enable")
    public void enable(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).enable();
    }

    public static void enable(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).enable();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Disable")
    public void disable(
            ) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).disable();
    }

    public static void disable(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).disable();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Is Enabled")
    public @ActionOutput(name = "enabled", type="boolean")
           Map<String, Object> isEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickSilentStepper)this.handler.getDevice()).isEnabled();
        result.put("enabled", value);
        return result;
    }

    public static Map<String, Object> isEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).isEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Basic Configuration")
    public void setBasicConfiguration(
            @ActionInput(name = "standstillCurrent") int standstillCurrent,
            @ActionInput(name = "motorRunCurrent") int motorRunCurrent,
            @ActionInput(name = "standstillDelayTime") int standstillDelayTime,
            @ActionInput(name = "powerDownTime") int powerDownTime,
            @ActionInput(name = "stealthThreshold") int stealthThreshold,
            @ActionInput(name = "coolstepThreshold") int coolstepThreshold,
            @ActionInput(name = "classicThreshold") int classicThreshold,
            @ActionInput(name = "highVelocityChopperMode") boolean highVelocityChopperMode) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setBasicConfiguration(standstillCurrent, motorRunCurrent, standstillDelayTime, powerDownTime, stealthThreshold, coolstepThreshold, classicThreshold, highVelocityChopperMode);
    }

    public static void setBasicConfiguration(@Nullable ThingActions actions, int standstillCurrent, int motorRunCurrent, int standstillDelayTime, int powerDownTime, int stealthThreshold, int coolstepThreshold, int classicThreshold, boolean highVelocityChopperMode) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setBasicConfiguration(standstillCurrent, motorRunCurrent, standstillDelayTime, powerDownTime, stealthThreshold, coolstepThreshold, classicThreshold, highVelocityChopperMode);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Basic Configuration")
    public @ActionOutput(name = "standstillCurrent", type="int")
           @ActionOutput(name = "motorRunCurrent", type="int")
           @ActionOutput(name = "standstillDelayTime", type="int")
           @ActionOutput(name = "powerDownTime", type="int")
           @ActionOutput(name = "stealthThreshold", type="int")
           @ActionOutput(name = "coolstepThreshold", type="int")
           @ActionOutput(name = "classicThreshold", type="int")
           @ActionOutput(name = "highVelocityChopperMode", type="boolean")
           Map<String, Object> getBasicConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.BasicConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getBasicConfiguration();
        result.put("standstillCurrent", value.standstillCurrent);
        result.put("motorRunCurrent", value.motorRunCurrent);
        result.put("standstillDelayTime", value.standstillDelayTime);
        result.put("powerDownTime", value.powerDownTime);
        result.put("stealthThreshold", value.stealthThreshold);
        result.put("coolstepThreshold", value.coolstepThreshold);
        result.put("classicThreshold", value.classicThreshold);
        result.put("highVelocityChopperMode", value.highVelocityChopperMode);
        return result;
    }

    public static Map<String, Object> getBasicConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getBasicConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Current Position")
    public void setCurrentPosition(
            @ActionInput(name = "position") int position) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setCurrentPosition(position);
    }

    public static void setCurrentPosition(@Nullable ThingActions actions, int position) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setCurrentPosition(position);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Current Position")
    public @ActionOutput(name = "position", type="int")
           Map<String, Object> getCurrentPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getCurrentPosition();
        result.put("position", value);
        return result;
    }

    public static Map<String, Object> getCurrentPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getCurrentPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Target Position")
    public void setTargetPosition(
            @ActionInput(name = "position") int position) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setTargetPosition(position);
    }

    public static void setTargetPosition(@Nullable ThingActions actions, int position) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setTargetPosition(position);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Target Position")
    public @ActionOutput(name = "position", type="int")
           Map<String, Object> getTargetPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getTargetPosition();
        result.put("position", value);
        return result;
    }

    public static Map<String, Object> getTargetPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getTargetPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Step Configuration")
    public void setStepConfiguration(
            @ActionInput(name = "stepResolution") short stepResolution,
            @ActionInput(name = "interpolation") boolean interpolation) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setStepConfiguration(stepResolution, interpolation);
    }

    public static void setStepConfiguration(@Nullable ThingActions actions, short stepResolution, boolean interpolation) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setStepConfiguration(stepResolution, interpolation);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Step Configuration")
    public @ActionOutput(name = "stepResolution", type="short")
           @ActionOutput(name = "interpolation", type="boolean")
           Map<String, Object> getStepConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.StepConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getStepConfiguration();
        result.put("stepResolution", value.stepResolution);
        result.put("interpolation", value.interpolation);
        return result;
    }

    public static Map<String, Object> getStepConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getStepConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Stack Input Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getStackInputVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getStackInputVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getStackInputVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getStackInputVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get External Input Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getExternalInputVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickSilentStepper)this.handler.getDevice()).getExternalInputVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getExternalInputVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getExternalInputVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Spreadcycle Configuration")
    public void setSpreadcycleConfiguration(
            @ActionInput(name = "slowDecayDuration") short slowDecayDuration,
            @ActionInput(name = "enableRandomSlowDecay") boolean enableRandomSlowDecay,
            @ActionInput(name = "fastDecayDuration") short fastDecayDuration,
            @ActionInput(name = "hysteresisStartValue") short hysteresisStartValue,
            @ActionInput(name = "hysteresisEndValue") byte hysteresisEndValue,
            @ActionInput(name = "sineWaveOffset") byte sineWaveOffset,
            @ActionInput(name = "chopperMode") short chopperMode,
            @ActionInput(name = "comparatorBlankTime") short comparatorBlankTime,
            @ActionInput(name = "fastDecayWithoutComparator") boolean fastDecayWithoutComparator) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setSpreadcycleConfiguration(slowDecayDuration, enableRandomSlowDecay, fastDecayDuration, hysteresisStartValue, hysteresisEndValue, sineWaveOffset, chopperMode, comparatorBlankTime, fastDecayWithoutComparator);
    }

    public static void setSpreadcycleConfiguration(@Nullable ThingActions actions, short slowDecayDuration, boolean enableRandomSlowDecay, short fastDecayDuration, short hysteresisStartValue, byte hysteresisEndValue, byte sineWaveOffset, short chopperMode, short comparatorBlankTime, boolean fastDecayWithoutComparator) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setSpreadcycleConfiguration(slowDecayDuration, enableRandomSlowDecay, fastDecayDuration, hysteresisStartValue, hysteresisEndValue, sineWaveOffset, chopperMode, comparatorBlankTime, fastDecayWithoutComparator);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Spreadcycle Configuration")
    public @ActionOutput(name = "slowDecayDuration", type="short")
           @ActionOutput(name = "enableRandomSlowDecay", type="boolean")
           @ActionOutput(name = "fastDecayDuration", type="short")
           @ActionOutput(name = "hysteresisStartValue", type="short")
           @ActionOutput(name = "hysteresisEndValue", type="byte")
           @ActionOutput(name = "sineWaveOffset", type="byte")
           @ActionOutput(name = "chopperMode", type="short")
           @ActionOutput(name = "comparatorBlankTime", type="short")
           @ActionOutput(name = "fastDecayWithoutComparator", type="boolean")
           Map<String, Object> getSpreadcycleConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.SpreadcycleConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getSpreadcycleConfiguration();
        result.put("slowDecayDuration", value.slowDecayDuration);
        result.put("enableRandomSlowDecay", value.enableRandomSlowDecay);
        result.put("fastDecayDuration", value.fastDecayDuration);
        result.put("hysteresisStartValue", value.hysteresisStartValue);
        result.put("hysteresisEndValue", value.hysteresisEndValue);
        result.put("sineWaveOffset", value.sineWaveOffset);
        result.put("chopperMode", value.chopperMode);
        result.put("comparatorBlankTime", value.comparatorBlankTime);
        result.put("fastDecayWithoutComparator", value.fastDecayWithoutComparator);
        return result;
    }

    public static Map<String, Object> getSpreadcycleConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getSpreadcycleConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Stealth Configuration")
    public void setStealthConfiguration(
            @ActionInput(name = "enableStealth") boolean enableStealth,
            @ActionInput(name = "amplitude") short amplitude,
            @ActionInput(name = "gradient") short gradient,
            @ActionInput(name = "enableAutoscale") boolean enableAutoscale,
            @ActionInput(name = "forceSymmetric") boolean forceSymmetric,
            @ActionInput(name = "freewheelMode") short freewheelMode) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setStealthConfiguration(enableStealth, amplitude, gradient, enableAutoscale, forceSymmetric, freewheelMode);
    }

    public static void setStealthConfiguration(@Nullable ThingActions actions, boolean enableStealth, short amplitude, short gradient, boolean enableAutoscale, boolean forceSymmetric, short freewheelMode) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setStealthConfiguration(enableStealth, amplitude, gradient, enableAutoscale, forceSymmetric, freewheelMode);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Stealth Configuration")
    public @ActionOutput(name = "enableStealth", type="boolean")
           @ActionOutput(name = "amplitude", type="short")
           @ActionOutput(name = "gradient", type="short")
           @ActionOutput(name = "enableAutoscale", type="boolean")
           @ActionOutput(name = "forceSymmetric", type="boolean")
           @ActionOutput(name = "freewheelMode", type="short")
           Map<String, Object> getStealthConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.StealthConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getStealthConfiguration();
        result.put("enableStealth", value.enableStealth);
        result.put("amplitude", value.amplitude);
        result.put("gradient", value.gradient);
        result.put("enableAutoscale", value.enableAutoscale);
        result.put("forceSymmetric", value.forceSymmetric);
        result.put("freewheelMode", value.freewheelMode);
        return result;
    }

    public static Map<String, Object> getStealthConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getStealthConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Coolstep Configuration")
    public void setCoolstepConfiguration(
            @ActionInput(name = "minimumStallguardValue") short minimumStallguardValue,
            @ActionInput(name = "maximumStallguardValue") short maximumStallguardValue,
            @ActionInput(name = "currentUpStepWidth") short currentUpStepWidth,
            @ActionInput(name = "currentDownStepWidth") short currentDownStepWidth,
            @ActionInput(name = "minimumCurrent") short minimumCurrent,
            @ActionInput(name = "stallguardThresholdValue") byte stallguardThresholdValue,
            @ActionInput(name = "stallguardMode") short stallguardMode) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setCoolstepConfiguration(minimumStallguardValue, maximumStallguardValue, currentUpStepWidth, currentDownStepWidth, minimumCurrent, stallguardThresholdValue, stallguardMode);
    }

    public static void setCoolstepConfiguration(@Nullable ThingActions actions, short minimumStallguardValue, short maximumStallguardValue, short currentUpStepWidth, short currentDownStepWidth, short minimumCurrent, byte stallguardThresholdValue, short stallguardMode) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setCoolstepConfiguration(minimumStallguardValue, maximumStallguardValue, currentUpStepWidth, currentDownStepWidth, minimumCurrent, stallguardThresholdValue, stallguardMode);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Coolstep Configuration")
    public @ActionOutput(name = "minimumStallguardValue", type="short")
           @ActionOutput(name = "maximumStallguardValue", type="short")
           @ActionOutput(name = "currentUpStepWidth", type="short")
           @ActionOutput(name = "currentDownStepWidth", type="short")
           @ActionOutput(name = "minimumCurrent", type="short")
           @ActionOutput(name = "stallguardThresholdValue", type="byte")
           @ActionOutput(name = "stallguardMode", type="short")
           Map<String, Object> getCoolstepConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.CoolstepConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getCoolstepConfiguration();
        result.put("minimumStallguardValue", value.minimumStallguardValue);
        result.put("maximumStallguardValue", value.maximumStallguardValue);
        result.put("currentUpStepWidth", value.currentUpStepWidth);
        result.put("currentDownStepWidth", value.currentDownStepWidth);
        result.put("minimumCurrent", value.minimumCurrent);
        result.put("stallguardThresholdValue", value.stallguardThresholdValue);
        result.put("stallguardMode", value.stallguardMode);
        return result;
    }

    public static Map<String, Object> getCoolstepConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getCoolstepConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Misc Configuration")
    public void setMiscConfiguration(
            @ActionInput(name = "disableShortToGroundProtection") boolean disableShortToGroundProtection,
            @ActionInput(name = "synchronizePhaseFrequency") short synchronizePhaseFrequency) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setMiscConfiguration(disableShortToGroundProtection, synchronizePhaseFrequency);
    }

    public static void setMiscConfiguration(@Nullable ThingActions actions, boolean disableShortToGroundProtection, short synchronizePhaseFrequency) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setMiscConfiguration(disableShortToGroundProtection, synchronizePhaseFrequency);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Misc Configuration")
    public @ActionOutput(name = "disableShortToGroundProtection", type="boolean")
           @ActionOutput(name = "synchronizePhaseFrequency", type="short")
           Map<String, Object> getMiscConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.MiscConfiguration value = ((BrickSilentStepper)this.handler.getDevice()).getMiscConfiguration();
        result.put("disableShortToGroundProtection", value.disableShortToGroundProtection);
        result.put("synchronizePhaseFrequency", value.synchronizePhaseFrequency);
        return result;
    }

    public static Map<String, Object> getMiscConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getMiscConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Driver Status")
    public @ActionOutput(name = "openLoad", type="short")
           @ActionOutput(name = "shortToGround", type="short")
           @ActionOutput(name = "overTemperature", type="short")
           @ActionOutput(name = "motorStalled", type="boolean")
           @ActionOutput(name = "actualMotorCurrent", type="short")
           @ActionOutput(name = "fullStepActive", type="boolean")
           @ActionOutput(name = "stallguardResult", type="short")
           @ActionOutput(name = "stealthVoltageAmplitude", type="short")
           Map<String, Object> getDriverStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.DriverStatus value = ((BrickSilentStepper)this.handler.getDevice()).getDriverStatus();
        result.put("openLoad", value.openLoad);
        result.put("shortToGround", value.shortToGround);
        result.put("overTemperature", value.overTemperature);
        result.put("motorStalled", value.motorStalled);
        result.put("actualMotorCurrent", value.actualMotorCurrent);
        result.put("fullStepActive", value.fullStepActive);
        result.put("stallguardResult", value.stallguardResult);
        result.put("stealthVoltageAmplitude", value.stealthVoltageAmplitude);
        return result;
    }

    public static Map<String, Object> getDriverStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getDriverStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Set Time Base")
    public void setTimeBase(
            @ActionInput(name = "timeBase") long timeBase) throws TinkerforgeException {
        ((BrickSilentStepper)this.handler.getDevice()).setTimeBase(timeBase);
    }

    public static void setTimeBase(@Nullable ThingActions actions, long timeBase) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            ((BrickSilentStepperActions) actions).setTimeBase(timeBase);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get Time Base")
    public @ActionOutput(name = "timeBase", type="long")
           Map<String, Object> getTimeBase(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickSilentStepper)this.handler.getDevice()).getTimeBase();
        result.put("timeBase", value);
        return result;
    }

    public static Map<String, Object> getTimeBase(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getTimeBase();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get All Data")
    public @ActionOutput(name = "currentVelocity", type="int")
           @ActionOutput(name = "currentPosition", type="int")
           @ActionOutput(name = "remainingSteps", type="int")
           @ActionOutput(name = "stackVoltage", type="int")
           @ActionOutput(name = "externalVoltage", type="int")
           @ActionOutput(name = "currentConsumption", type="int")
           Map<String, Object> getAllData(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickSilentStepper.AllData value = ((BrickSilentStepper)this.handler.getDevice()).getAllData();
        result.put("currentVelocity", value.currentVelocity);
        result.put("currentPosition", value.currentPosition);
        result.put("remainingSteps", value.remainingSteps);
        result.put("stackVoltage", value.stackVoltage);
        result.put("externalVoltage", value.externalVoltage);
        result.put("currentConsumption", value.currentConsumption);
        return result;
    }

    public static Map<String, Object> getAllData(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getAllData();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }

    @RuleAction(label = "Get All Data Period")
    public @ActionOutput(name = "period", type="long")
           Map<String, Object> getAllDataPeriod(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickSilentStepper)this.handler.getDevice()).getAllDataPeriod();
        result.put("period", value);
        return result;
    }

    public static Map<String, Object> getAllDataPeriod(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickSilentStepperActions) {
            return ((BrickSilentStepperActions) actions).getAllDataPeriod();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickSilentStepperActions class.");
        }
    }
}
