package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickStepperActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Set Max Velocity")
    public void setMaxVelocity(
            @ActionInput(name = "velocity") int velocity) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setMaxVelocity(velocity);
    }

    public static void setMaxVelocity(@Nullable ThingActions actions, int velocity) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setMaxVelocity(velocity);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Max Velocity")
    public @ActionOutput(name = "velocity", type="int")
           Map<String, Object> getMaxVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getMaxVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getMaxVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getMaxVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Current Velocity")
    public @ActionOutput(name = "velocity", type="int")
           Map<String, Object> getCurrentVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getCurrentVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getCurrentVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getCurrentVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Speed Ramping")
    public void setSpeedRamping(
            @ActionInput(name = "acceleration") int acceleration,
            @ActionInput(name = "deacceleration") int deacceleration) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setSpeedRamping(acceleration, deacceleration);
    }

    public static void setSpeedRamping(@Nullable ThingActions actions, int acceleration, int deacceleration) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setSpeedRamping(acceleration, deacceleration);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Speed Ramping")
    public @ActionOutput(name = "acceleration", type="int")
           @ActionOutput(name = "deacceleration", type="int")
           Map<String, Object> getSpeedRamping(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickStepper.SpeedRamping value = ((BrickStepper)this.handler.getDevice()).getSpeedRamping();
        result.put("acceleration", value.acceleration);
        result.put("deacceleration", value.deacceleration);
        return result;
    }

    public static Map<String, Object> getSpeedRamping(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getSpeedRamping();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Full Brake")
    public void fullBrake(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).fullBrake();
    }

    public static void fullBrake(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).fullBrake();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Steps")
    public void setSteps(
            @ActionInput(name = "steps") int steps) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setSteps(steps);
    }

    public static void setSteps(@Nullable ThingActions actions, int steps) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setSteps(steps);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Steps")
    public @ActionOutput(name = "steps", type="int")
           Map<String, Object> getSteps(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getSteps();
        result.put("steps", value);
        return result;
    }

    public static Map<String, Object> getSteps(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getSteps();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Remaining Steps")
    public @ActionOutput(name = "steps", type="int")
           Map<String, Object> getRemainingSteps(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getRemainingSteps();
        result.put("steps", value);
        return result;
    }

    public static Map<String, Object> getRemainingSteps(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getRemainingSteps();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Drive Forward")
    public void driveForward(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).driveForward();
    }

    public static void driveForward(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).driveForward();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Drive Backward")
    public void driveBackward(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).driveBackward();
    }

    public static void driveBackward(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).driveBackward();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Stop")
    public void stop(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).stop();
    }

    public static void stop(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).stop();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Motor Current")
    public void setMotorCurrent(
            @ActionInput(name = "current") int current) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setMotorCurrent(current);
    }

    public static void setMotorCurrent(@Nullable ThingActions actions, int current) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setMotorCurrent(current);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Motor Current")
    public @ActionOutput(name = "current", type="int")
           Map<String, Object> getMotorCurrent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getMotorCurrent();
        result.put("current", value);
        return result;
    }

    public static Map<String, Object> getMotorCurrent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getMotorCurrent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Enable")
    public void enable(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).enable();
    }

    public static void enable(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).enable();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Disable")
    public void disable(
            ) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).disable();
    }

    public static void disable(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).disable();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Is Enabled")
    public @ActionOutput(name = "enabled", type="boolean")
           Map<String, Object> isEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickStepper)this.handler.getDevice()).isEnabled();
        result.put("enabled", value);
        return result;
    }

    public static Map<String, Object> isEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).isEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Current Position")
    public void setCurrentPosition(
            @ActionInput(name = "position") int position) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setCurrentPosition(position);
    }

    public static void setCurrentPosition(@Nullable ThingActions actions, int position) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setCurrentPosition(position);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Current Position")
    public @ActionOutput(name = "position", type="int")
           Map<String, Object> getCurrentPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getCurrentPosition();
        result.put("position", value);
        return result;
    }

    public static Map<String, Object> getCurrentPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getCurrentPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Target Position")
    public void setTargetPosition(
            @ActionInput(name = "position") int position) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setTargetPosition(position);
    }

    public static void setTargetPosition(@Nullable ThingActions actions, int position) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setTargetPosition(position);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Target Position")
    public @ActionOutput(name = "position", type="int")
           Map<String, Object> getTargetPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getTargetPosition();
        result.put("position", value);
        return result;
    }

    public static Map<String, Object> getTargetPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getTargetPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Step Mode")
    public void setStepMode(
            @ActionInput(name = "mode") short mode) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setStepMode(mode);
    }

    public static void setStepMode(@Nullable ThingActions actions, short mode) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setStepMode(mode);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Step Mode")
    public @ActionOutput(name = "mode", type="short")
           Map<String, Object> getStepMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickStepper)this.handler.getDevice()).getStepMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> getStepMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getStepMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Stack Input Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getStackInputVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getStackInputVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getStackInputVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getStackInputVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get External Input Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getExternalInputVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getExternalInputVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getExternalInputVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getExternalInputVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Current Consumption")
    public @ActionOutput(name = "current", type="int")
           Map<String, Object> getCurrentConsumption(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getCurrentConsumption();
        result.put("current", value);
        return result;
    }

    public static Map<String, Object> getCurrentConsumption(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getCurrentConsumption();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Decay")
    public void setDecay(
            @ActionInput(name = "decay") int decay) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setDecay(decay);
    }

    public static void setDecay(@Nullable ThingActions actions, int decay) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setDecay(decay);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Decay")
    public @ActionOutput(name = "decay", type="int")
           Map<String, Object> getDecay(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickStepper)this.handler.getDevice()).getDecay();
        result.put("decay", value);
        return result;
    }

    public static Map<String, Object> getDecay(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getDecay();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Sync Rect")
    public void setSyncRect(
            @ActionInput(name = "syncRect") boolean syncRect) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setSyncRect(syncRect);
    }

    public static void setSyncRect(@Nullable ThingActions actions, boolean syncRect) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setSyncRect(syncRect);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Is Sync Rect")
    public @ActionOutput(name = "syncRect", type="boolean")
           Map<String, Object> isSyncRect(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickStepper)this.handler.getDevice()).isSyncRect();
        result.put("syncRect", value);
        return result;
    }

    public static Map<String, Object> isSyncRect(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).isSyncRect();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Set Time Base")
    public void setTimeBase(
            @ActionInput(name = "timeBase") long timeBase) throws TinkerforgeException {
        ((BrickStepper)this.handler.getDevice()).setTimeBase(timeBase);
    }

    public static void setTimeBase(@Nullable ThingActions actions, long timeBase) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            ((BrickStepperActions) actions).setTimeBase(timeBase);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get Time Base")
    public @ActionOutput(name = "timeBase", type="long")
           Map<String, Object> getTimeBase(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickStepper)this.handler.getDevice()).getTimeBase();
        result.put("timeBase", value);
        return result;
    }

    public static Map<String, Object> getTimeBase(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getTimeBase();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get All Data")
    public @ActionOutput(name = "currentVelocity", type="int")
           @ActionOutput(name = "currentPosition", type="int")
           @ActionOutput(name = "remainingSteps", type="int")
           @ActionOutput(name = "stackVoltage", type="int")
           @ActionOutput(name = "externalVoltage", type="int")
           @ActionOutput(name = "currentConsumption", type="int")
           Map<String, Object> getAllData(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickStepper.AllData value = ((BrickStepper)this.handler.getDevice()).getAllData();
        result.put("currentVelocity", value.currentVelocity);
        result.put("currentPosition", value.currentPosition);
        result.put("remainingSteps", value.remainingSteps);
        result.put("stackVoltage", value.stackVoltage);
        result.put("externalVoltage", value.externalVoltage);
        result.put("currentConsumption", value.currentConsumption);
        return result;
    }

    public static Map<String, Object> getAllData(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getAllData();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }

    @RuleAction(label = "Get All Data Period")
    public @ActionOutput(name = "period", type="long")
           Map<String, Object> getAllDataPeriod(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickStepper)this.handler.getDevice()).getAllDataPeriod();
        result.put("period", value);
        return result;
    }

    public static Map<String, Object> getAllDataPeriod(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickStepperActions) {
            return ((BrickStepperActions) actions).getAllDataPeriod();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickStepperActions class.");
        }
    }
}
