package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletAccelerometerV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Acceleration")
    public @ActionOutput(name = "x", type="int")
           @ActionOutput(name = "y", type="int")
           @ActionOutput(name = "z", type="int")
           Map<String, Object> getAcceleration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAccelerometerV2.Acceleration value = ((BrickletAccelerometerV2)this.handler.getDevice()).getAcceleration();
        result.put("x", value.x);
        result.put("y", value.y);
        result.put("z", value.z);
        return result;
    }

    public static Map<String, Object> getAcceleration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAccelerometerV2Actions) {
            return ((BrickletAccelerometerV2Actions) actions).getAcceleration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAccelerometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "dataRate", type="int")
           @ActionOutput(name = "fullScale", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAccelerometerV2.Configuration value = ((BrickletAccelerometerV2)this.handler.getDevice()).getConfiguration();
        result.put("dataRate", value.dataRate);
        result.put("fullScale", value.fullScale);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAccelerometerV2Actions) {
            return ((BrickletAccelerometerV2Actions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAccelerometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Info LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getInfoLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAccelerometerV2)this.handler.getDevice()).getInfoLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getInfoLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAccelerometerV2Actions) {
            return ((BrickletAccelerometerV2Actions) actions).getInfoLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAccelerometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Filter Configuration")
    public @ActionOutput(name = "iirBypass", type="int")
           @ActionOutput(name = "lowPassFilter", type="int")
           Map<String, Object> getFilterConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAccelerometerV2.FilterConfiguration value = ((BrickletAccelerometerV2)this.handler.getDevice()).getFilterConfiguration();
        result.put("iirBypass", value.iirBypass);
        result.put("lowPassFilter", value.lowPassFilter);
        return result;
    }

    public static Map<String, Object> getFilterConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAccelerometerV2Actions) {
            return ((BrickletAccelerometerV2Actions) actions).getFilterConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAccelerometerV2Actions class.");
        }
    }
}
