package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletAirQualityActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get All Values")
    public @ActionOutput(name = "iaqIndex", type="int")
           @ActionOutput(name = "iaqIndexAccuracy", type="int")
           @ActionOutput(name = "temperature", type="int")
           @ActionOutput(name = "humidity", type="int")
           @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getAllValues(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAirQuality.AllValues value = ((BrickletAirQuality)this.handler.getDevice()).getAllValues();
        result.put("iaqIndex", value.iaqIndex);
        result.put("iaqIndexAccuracy", value.iaqIndexAccuracy);
        result.put("temperature", value.temperature);
        result.put("humidity", value.humidity);
        result.put("airPressure", value.airPressure);
        return result;
    }

    public static Map<String, Object> getAllValues(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getAllValues();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get Temperature Offset")
    public @ActionOutput(name = "offset", type="int")
           Map<String, Object> getTemperatureOffset(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAirQuality)this.handler.getDevice()).getTemperatureOffset();
        result.put("offset", value);
        return result;
    }

    public static Map<String, Object> getTemperatureOffset(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getTemperatureOffset();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get IAQ Index")
    public @ActionOutput(name = "iaqIndex", type="int")
           @ActionOutput(name = "iaqIndexAccuracy", type="int")
           Map<String, Object> getIAQIndex(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAirQuality.IAQIndex value = ((BrickletAirQuality)this.handler.getDevice()).getIAQIndex();
        result.put("iaqIndex", value.iaqIndex);
        result.put("iaqIndexAccuracy", value.iaqIndexAccuracy);
        return result;
    }

    public static Map<String, Object> getIAQIndex(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getIAQIndex();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAirQuality)this.handler.getDevice()).getTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get Humidity")
    public @ActionOutput(name = "humidity", type="int")
           Map<String, Object> getHumidity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAirQuality)this.handler.getDevice()).getHumidity();
        result.put("humidity", value);
        return result;
    }

    public static Map<String, Object> getHumidity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getHumidity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAirQuality)this.handler.getDevice()).getAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }

    @RuleAction(label = "Get Background Calibration Duration")
    public @ActionOutput(name = "duration", type="int")
           Map<String, Object> getBackgroundCalibrationDuration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAirQuality)this.handler.getDevice()).getBackgroundCalibrationDuration();
        result.put("duration", value);
        return result;
    }

    public static Map<String, Object> getBackgroundCalibrationDuration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAirQualityActions) {
            return ((BrickletAirQualityActions) actions).getBackgroundCalibrationDuration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAirQualityActions class.");
        }
    }
}
