package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletAnalogInActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAnalogIn)this.handler.getDevice()).getVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInActions) {
            return ((BrickletAnalogInActions) actions).getVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInActions class.");
        }
    }

    @RuleAction(label = "Get Analog Value")
    public @ActionOutput(name = "value", type="int")
           Map<String, Object> getAnalogValue(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAnalogIn)this.handler.getDevice()).getAnalogValue();
        result.put("value", value);
        return result;
    }

    public static Map<String, Object> getAnalogValue(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInActions) {
            return ((BrickletAnalogInActions) actions).getAnalogValue();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInActions class.");
        }
    }

    @RuleAction(label = "Get Averaging")
    public @ActionOutput(name = "average", type="short")
           Map<String, Object> getAveraging(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletAnalogIn)this.handler.getDevice()).getAveraging();
        result.put("average", value);
        return result;
    }

    public static Map<String, Object> getAveraging(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInActions) {
            return ((BrickletAnalogInActions) actions).getAveraging();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInActions class.");
        }
    }
}
