package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletAnalogInV3Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAnalogInV3)this.handler.getDevice()).getVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInV3Actions) {
            return ((BrickletAnalogInV3Actions) actions).getVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInV3Actions class.");
        }
    }

    @RuleAction(label = "Get Oversampling")
    public @ActionOutput(name = "oversampling", type="int")
           Map<String, Object> getOversampling(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletAnalogInV3)this.handler.getDevice()).getOversampling();
        result.put("oversampling", value);
        return result;
    }

    public static Map<String, Object> getOversampling(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInV3Actions) {
            return ((BrickletAnalogInV3Actions) actions).getOversampling();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInV3Actions class.");
        }
    }

    @RuleAction(label = "Get Calibration")
    public @ActionOutput(name = "offset", type="int")
           @ActionOutput(name = "multiplier", type="int")
           @ActionOutput(name = "divisor", type="int")
           Map<String, Object> getCalibration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletAnalogInV3.Calibration value = ((BrickletAnalogInV3)this.handler.getDevice()).getCalibration();
        result.put("offset", value.offset);
        result.put("multiplier", value.multiplier);
        result.put("divisor", value.divisor);
        return result;
    }

    public static Map<String, Object> getCalibration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletAnalogInV3Actions) {
            return ((BrickletAnalogInV3Actions) actions).getCalibration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletAnalogInV3Actions class.");
        }
    }
}
