package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletBarometerActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometer)this.handler.getDevice()).getAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerActions) {
            return ((BrickletBarometerActions) actions).getAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerActions class.");
        }
    }

    @RuleAction(label = "Get Altitude")
    public @ActionOutput(name = "altitude", type="int")
           Map<String, Object> getAltitude(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometer)this.handler.getDevice()).getAltitude();
        result.put("altitude", value);
        return result;
    }

    public static Map<String, Object> getAltitude(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerActions) {
            return ((BrickletBarometerActions) actions).getAltitude();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerActions class.");
        }
    }

    @RuleAction(label = "Get Reference Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getReferenceAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometer)this.handler.getDevice()).getReferenceAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getReferenceAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerActions) {
            return ((BrickletBarometerActions) actions).getReferenceAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerActions class.");
        }
    }

    @RuleAction(label = "Get Averaging")
    public @ActionOutput(name = "movingAveragePressure", type="short")
           @ActionOutput(name = "averagePressure", type="short")
           @ActionOutput(name = "averageTemperature", type="short")
           Map<String, Object> getAveraging(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletBarometer.Averaging value = ((BrickletBarometer)this.handler.getDevice()).getAveraging();
        result.put("movingAveragePressure", value.movingAveragePressure);
        result.put("averagePressure", value.averagePressure);
        result.put("averageTemperature", value.averageTemperature);
        return result;
    }

    public static Map<String, Object> getAveraging(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerActions) {
            return ((BrickletBarometerActions) actions).getAveraging();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerActions class.");
        }
    }
}
