package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletBarometerV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometerV2)this.handler.getDevice()).getAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerV2Actions) {
            return ((BrickletBarometerV2Actions) actions).getAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Altitude")
    public @ActionOutput(name = "altitude", type="int")
           Map<String, Object> getAltitude(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometerV2)this.handler.getDevice()).getAltitude();
        result.put("altitude", value);
        return result;
    }

    public static Map<String, Object> getAltitude(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerV2Actions) {
            return ((BrickletBarometerV2Actions) actions).getAltitude();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometerV2)this.handler.getDevice()).getTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerV2Actions) {
            return ((BrickletBarometerV2Actions) actions).getTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Moving Average Configuration")
    public @ActionOutput(name = "movingAverageLengthAirPressure", type="int")
           @ActionOutput(name = "movingAverageLengthTemperature", type="int")
           Map<String, Object> getMovingAverageConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletBarometerV2.MovingAverageConfiguration value = ((BrickletBarometerV2)this.handler.getDevice()).getMovingAverageConfiguration();
        result.put("movingAverageLengthAirPressure", value.movingAverageLengthAirPressure);
        result.put("movingAverageLengthTemperature", value.movingAverageLengthTemperature);
        return result;
    }

    public static Map<String, Object> getMovingAverageConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerV2Actions) {
            return ((BrickletBarometerV2Actions) actions).getMovingAverageConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Reference Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getReferenceAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletBarometerV2)this.handler.getDevice()).getReferenceAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getReferenceAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletBarometerV2Actions) {
            return ((BrickletBarometerV2Actions) actions).getReferenceAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletBarometerV2Actions class.");
        }
    }
}
