package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletCO2V2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get All Values")
    public @ActionOutput(name = "co2Concentration", type="int")
           @ActionOutput(name = "temperature", type="int")
           @ActionOutput(name = "humidity", type="int")
           Map<String, Object> getAllValues(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletCO2V2.AllValues value = ((BrickletCO2V2)this.handler.getDevice()).getAllValues();
        result.put("co2Concentration", value.co2Concentration);
        result.put("temperature", value.temperature);
        result.put("humidity", value.humidity);
        return result;
    }

    public static Map<String, Object> getAllValues(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getAllValues();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }

    @RuleAction(label = "Get Air Pressure")
    public @ActionOutput(name = "airPressure", type="int")
           Map<String, Object> getAirPressure(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCO2V2)this.handler.getDevice()).getAirPressure();
        result.put("airPressure", value);
        return result;
    }

    public static Map<String, Object> getAirPressure(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getAirPressure();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }

    @RuleAction(label = "Get Temperature Offset")
    public @ActionOutput(name = "offset", type="int")
           Map<String, Object> getTemperatureOffset(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCO2V2)this.handler.getDevice()).getTemperatureOffset();
        result.put("offset", value);
        return result;
    }

    public static Map<String, Object> getTemperatureOffset(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getTemperatureOffset();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }

    @RuleAction(label = "Get CO2 Concentration")
    public @ActionOutput(name = "co2Concentration", type="int")
           Map<String, Object> getCO2Concentration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCO2V2)this.handler.getDevice()).getCO2Concentration();
        result.put("co2Concentration", value);
        return result;
    }

    public static Map<String, Object> getCO2Concentration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getCO2Concentration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }

    @RuleAction(label = "Get Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCO2V2)this.handler.getDevice()).getTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }

    @RuleAction(label = "Get Humidity")
    public @ActionOutput(name = "humidity", type="int")
           Map<String, Object> getHumidity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletCO2V2)this.handler.getDevice()).getHumidity();
        result.put("humidity", value);
        return result;
    }

    public static Map<String, Object> getHumidity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletCO2V2Actions) {
            return ((BrickletCO2V2Actions) actions).getHumidity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletCO2V2Actions class.");
        }
    }
}
