package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletColorActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Color")
    public @ActionOutput(name = "r", type="int")
           @ActionOutput(name = "g", type="int")
           @ActionOutput(name = "b", type="int")
           @ActionOutput(name = "c", type="int")
           Map<String, Object> getColor(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletColor.Color value = ((BrickletColor)this.handler.getDevice()).getColor();
        result.put("r", value.r);
        result.put("g", value.g);
        result.put("b", value.b);
        result.put("c", value.c);
        return result;
    }

    public static Map<String, Object> getColor(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorActions) {
            return ((BrickletColorActions) actions).getColor();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorActions class.");
        }
    }

    @RuleAction(label = "Is Light On")
    public @ActionOutput(name = "light", type="short")
           Map<String, Object> isLightOn(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletColor)this.handler.getDevice()).isLightOn();
        result.put("light", value);
        return result;
    }

    public static Map<String, Object> isLightOn(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorActions) {
            return ((BrickletColorActions) actions).isLightOn();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorActions class.");
        }
    }

    @RuleAction(label = "Get Config")
    public @ActionOutput(name = "gain", type="short")
           @ActionOutput(name = "integrationTime", type="short")
           Map<String, Object> getConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletColor.Config value = ((BrickletColor)this.handler.getDevice()).getConfig();
        result.put("gain", value.gain);
        result.put("integrationTime", value.integrationTime);
        return result;
    }

    public static Map<String, Object> getConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorActions) {
            return ((BrickletColorActions) actions).getConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorActions class.");
        }
    }

    @RuleAction(label = "Get Illuminance")
    public @ActionOutput(name = "illuminance", type="long")
           Map<String, Object> getIlluminance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletColor)this.handler.getDevice()).getIlluminance();
        result.put("illuminance", value);
        return result;
    }

    public static Map<String, Object> getIlluminance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorActions) {
            return ((BrickletColorActions) actions).getIlluminance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorActions class.");
        }
    }

    @RuleAction(label = "Get Color Temperature")
    public @ActionOutput(name = "colorTemperature", type="int")
           Map<String, Object> getColorTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletColor)this.handler.getDevice()).getColorTemperature();
        result.put("colorTemperature", value);
        return result;
    }

    public static Map<String, Object> getColorTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorActions) {
            return ((BrickletColorActions) actions).getColorTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorActions class.");
        }
    }
}
