package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletColorV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Color")
    public @ActionOutput(name = "r", type="int")
           @ActionOutput(name = "g", type="int")
           @ActionOutput(name = "b", type="int")
           @ActionOutput(name = "c", type="int")
           Map<String, Object> getColor(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletColorV2.Color value = ((BrickletColorV2)this.handler.getDevice()).getColor();
        result.put("r", value.r);
        result.put("g", value.g);
        result.put("b", value.b);
        result.put("c", value.c);
        return result;
    }

    public static Map<String, Object> getColor(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorV2Actions) {
            return ((BrickletColorV2Actions) actions).getColor();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorV2Actions class.");
        }
    }

    @RuleAction(label = "Get Illuminance")
    public @ActionOutput(name = "illuminance", type="long")
           Map<String, Object> getIlluminance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletColorV2)this.handler.getDevice()).getIlluminance();
        result.put("illuminance", value);
        return result;
    }

    public static Map<String, Object> getIlluminance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorV2Actions) {
            return ((BrickletColorV2Actions) actions).getIlluminance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorV2Actions class.");
        }
    }

    @RuleAction(label = "Get Color Temperature")
    public @ActionOutput(name = "colorTemperature", type="int")
           Map<String, Object> getColorTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletColorV2)this.handler.getDevice()).getColorTemperature();
        result.put("colorTemperature", value);
        return result;
    }

    public static Map<String, Object> getColorTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorV2Actions) {
            return ((BrickletColorV2Actions) actions).getColorTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorV2Actions class.");
        }
    }

    @RuleAction(label = "Get Light")
    public @ActionOutput(name = "enable", type="boolean")
           Map<String, Object> getLight(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletColorV2)this.handler.getDevice()).getLight();
        result.put("enable", value);
        return result;
    }

    public static Map<String, Object> getLight(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorV2Actions) {
            return ((BrickletColorV2Actions) actions).getLight();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "gain", type="int")
           @ActionOutput(name = "integrationTime", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletColorV2.Configuration value = ((BrickletColorV2)this.handler.getDevice()).getConfiguration();
        result.put("gain", value.gain);
        result.put("integrationTime", value.integrationTime);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletColorV2Actions) {
            return ((BrickletColorV2Actions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletColorV2Actions class.");
        }
    }
}
