package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletDMXActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Write Frame")
    public void writeFrame(
            @ActionInput(name = "frame") int[] frame) throws TinkerforgeException {
        ((BrickletDMX)this.handler.getDevice()).writeFrame(frame);
    }

    public static void writeFrame(@Nullable ThingActions actions, int[] frame) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            ((BrickletDMXActions) actions).writeFrame(frame);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Get DMX Mode")
    public @ActionOutput(name = "dmxMode", type="int")
           Map<String, Object> getDMXMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDMX)this.handler.getDevice()).getDMXMode();
        result.put("dmxMode", value);
        return result;
    }

    public static Map<String, Object> getDMXMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).getDMXMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Read Frame")
    public @ActionOutput(name = "frame", type="int[]")
           @ActionOutput(name = "frameNumber", type="long")
           Map<String, Object> readFrame(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletDMX.ReadFrame value = ((BrickletDMX)this.handler.getDevice()).readFrame();
        result.put("frame", value.frame);
        result.put("frameNumber", value.frameNumber);
        return result;
    }

    public static Map<String, Object> readFrame(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).readFrame();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Get Frame Duration")
    public @ActionOutput(name = "frameDuration", type="int")
           Map<String, Object> getFrameDuration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDMX)this.handler.getDevice()).getFrameDuration();
        result.put("frameDuration", value);
        return result;
    }

    public static Map<String, Object> getFrameDuration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).getFrameDuration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Get Frame Error Count")
    public @ActionOutput(name = "overrunErrorCount", type="long")
           @ActionOutput(name = "framingErrorCount", type="long")
           Map<String, Object> getFrameErrorCount(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletDMX.FrameErrorCount value = ((BrickletDMX)this.handler.getDevice()).getFrameErrorCount();
        result.put("overrunErrorCount", value.overrunErrorCount);
        result.put("framingErrorCount", value.framingErrorCount);
        return result;
    }

    public static Map<String, Object> getFrameErrorCount(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).getFrameErrorCount();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Get Communication LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getCommunicationLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDMX)this.handler.getDevice()).getCommunicationLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getCommunicationLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).getCommunicationLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }

    @RuleAction(label = "Get Error LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getErrorLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDMX)this.handler.getDevice()).getErrorLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getErrorLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDMXActions) {
            return ((BrickletDMXActions) actions).getErrorLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDMXActions class.");
        }
    }
}
