package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletDistanceIRActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Distance")
    public @ActionOutput(name = "distance", type="int")
           Map<String, Object> getDistance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDistanceIR)this.handler.getDevice()).getDistance();
        result.put("distance", value);
        return result;
    }

    public static Map<String, Object> getDistance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDistanceIRActions) {
            return ((BrickletDistanceIRActions) actions).getDistance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDistanceIRActions class.");
        }
    }

    @RuleAction(label = "Get Analog Value")
    public @ActionOutput(name = "value", type="int")
           Map<String, Object> getAnalogValue(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDistanceIR)this.handler.getDevice()).getAnalogValue();
        result.put("value", value);
        return result;
    }

    public static Map<String, Object> getAnalogValue(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDistanceIRActions) {
            return ((BrickletDistanceIRActions) actions).getAnalogValue();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDistanceIRActions class.");
        }
    }

    @RuleAction(label = "Get Sampling Point")
    public @ActionOutput(name = "distance", type="int")
           Map<String, Object> getSamplingPoint(
            @ActionInput(name = "position") short position) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDistanceIR)this.handler.getDevice()).getSamplingPoint(position);
        result.put("distance", value);
        return result;
    }

    public static Map<String, Object> getSamplingPoint(@Nullable ThingActions actions, short position) throws TinkerforgeException {
        if (actions instanceof BrickletDistanceIRActions) {
            return ((BrickletDistanceIRActions) actions).getSamplingPoint(position);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDistanceIRActions class.");
        }
    }
}
