package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletDustDetectorActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Dust Density")
    public @ActionOutput(name = "dustDensity", type="int")
           Map<String, Object> getDustDensity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletDustDetector)this.handler.getDevice()).getDustDensity();
        result.put("dustDensity", value);
        return result;
    }

    public static Map<String, Object> getDustDensity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDustDetectorActions) {
            return ((BrickletDustDetectorActions) actions).getDustDensity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDustDetectorActions class.");
        }
    }

    @RuleAction(label = "Get Moving Average")
    public @ActionOutput(name = "average", type="short")
           Map<String, Object> getMovingAverage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletDustDetector)this.handler.getDevice()).getMovingAverage();
        result.put("average", value);
        return result;
    }

    public static Map<String, Object> getMovingAverage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletDustDetectorActions) {
            return ((BrickletDustDetectorActions) actions).getMovingAverage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletDustDetectorActions class.");
        }
    }
}
