package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletEnergyMonitorActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Energy Data")
    public @ActionOutput(name = "voltage", type="int")
           @ActionOutput(name = "current", type="int")
           @ActionOutput(name = "energy", type="int")
           @ActionOutput(name = "realPower", type="int")
           @ActionOutput(name = "apparentPower", type="int")
           @ActionOutput(name = "reactivePower", type="int")
           @ActionOutput(name = "powerFactor", type="int")
           @ActionOutput(name = "frequency", type="int")
           Map<String, Object> getEnergyData(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletEnergyMonitor.EnergyData value = ((BrickletEnergyMonitor)this.handler.getDevice()).getEnergyData();
        result.put("voltage", value.voltage);
        result.put("current", value.current);
        result.put("energy", value.energy);
        result.put("realPower", value.realPower);
        result.put("apparentPower", value.apparentPower);
        result.put("reactivePower", value.reactivePower);
        result.put("powerFactor", value.powerFactor);
        result.put("frequency", value.frequency);
        return result;
    }

    public static Map<String, Object> getEnergyData(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletEnergyMonitorActions) {
            return ((BrickletEnergyMonitorActions) actions).getEnergyData();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletEnergyMonitorActions class.");
        }
    }

    @RuleAction(label = "Reset Energy")
    public void resetEnergy(
            ) throws TinkerforgeException {
        ((BrickletEnergyMonitor)this.handler.getDevice()).resetEnergy();
    }

    public static void resetEnergy(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletEnergyMonitorActions) {
            ((BrickletEnergyMonitorActions) actions).resetEnergy();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletEnergyMonitorActions class.");
        }
    }

    @RuleAction(label = "Get Waveform")
    public @ActionOutput(name = "waveform", type="int[]")
           Map<String, Object> getWaveform(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int[] value = ((BrickletEnergyMonitor)this.handler.getDevice()).getWaveform();
        result.put("waveform", value);
        return result;
    }

    public static Map<String, Object> getWaveform(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletEnergyMonitorActions) {
            return ((BrickletEnergyMonitorActions) actions).getWaveform();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletEnergyMonitorActions class.");
        }
    }

    @RuleAction(label = "Get Transformer Status")
    public @ActionOutput(name = "voltageTransformerConnected", type="boolean")
           @ActionOutput(name = "currentTransformerConnected", type="boolean")
           Map<String, Object> getTransformerStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletEnergyMonitor.TransformerStatus value = ((BrickletEnergyMonitor)this.handler.getDevice()).getTransformerStatus();
        result.put("voltageTransformerConnected", value.voltageTransformerConnected);
        result.put("currentTransformerConnected", value.currentTransformerConnected);
        return result;
    }

    public static Map<String, Object> getTransformerStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletEnergyMonitorActions) {
            return ((BrickletEnergyMonitorActions) actions).getTransformerStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletEnergyMonitorActions class.");
        }
    }

    @RuleAction(label = "Get Transformer Calibration")
    public @ActionOutput(name = "voltageRatio", type="int")
           @ActionOutput(name = "currentRatio", type="int")
           @ActionOutput(name = "phaseShift", type="int")
           Map<String, Object> getTransformerCalibration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletEnergyMonitor.TransformerCalibration value = ((BrickletEnergyMonitor)this.handler.getDevice()).getTransformerCalibration();
        result.put("voltageRatio", value.voltageRatio);
        result.put("currentRatio", value.currentRatio);
        result.put("phaseShift", value.phaseShift);
        return result;
    }

    public static Map<String, Object> getTransformerCalibration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletEnergyMonitorActions) {
            return ((BrickletEnergyMonitorActions) actions).getTransformerCalibration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletEnergyMonitorActions class.");
        }
    }
}
