package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletGPSActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Coordinates")
    public @ActionOutput(name = "latitude", type="long")
           @ActionOutput(name = "ns", type="char")
           @ActionOutput(name = "longitude", type="long")
           @ActionOutput(name = "ew", type="char")
           @ActionOutput(name = "pdop", type="int")
           @ActionOutput(name = "hdop", type="int")
           @ActionOutput(name = "vdop", type="int")
           @ActionOutput(name = "epe", type="int")
           Map<String, Object> getCoordinates(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPS.Coordinates value = ((BrickletGPS)this.handler.getDevice()).getCoordinates();
        result.put("latitude", value.latitude);
        result.put("ns", value.ns);
        result.put("longitude", value.longitude);
        result.put("ew", value.ew);
        result.put("pdop", value.pdop);
        result.put("hdop", value.hdop);
        result.put("vdop", value.vdop);
        result.put("epe", value.epe);
        return result;
    }

    public static Map<String, Object> getCoordinates(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            return ((BrickletGPSActions) actions).getCoordinates();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }

    @RuleAction(label = "Get Status")
    public @ActionOutput(name = "fix", type="short")
           @ActionOutput(name = "satellitesView", type="short")
           @ActionOutput(name = "satellitesUsed", type="short")
           Map<String, Object> getStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPS.Status value = ((BrickletGPS)this.handler.getDevice()).getStatus();
        result.put("fix", value.fix);
        result.put("satellitesView", value.satellitesView);
        result.put("satellitesUsed", value.satellitesUsed);
        return result;
    }

    public static Map<String, Object> getStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            return ((BrickletGPSActions) actions).getStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }

    @RuleAction(label = "Get Altitude")
    public @ActionOutput(name = "altitude", type="int")
           @ActionOutput(name = "geoidalSeparation", type="int")
           Map<String, Object> getAltitude(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPS.Altitude value = ((BrickletGPS)this.handler.getDevice()).getAltitude();
        result.put("altitude", value.altitude);
        result.put("geoidalSeparation", value.geoidalSeparation);
        return result;
    }

    public static Map<String, Object> getAltitude(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            return ((BrickletGPSActions) actions).getAltitude();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }

    @RuleAction(label = "Get Motion")
    public @ActionOutput(name = "course", type="long")
           @ActionOutput(name = "speed", type="long")
           Map<String, Object> getMotion(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPS.Motion value = ((BrickletGPS)this.handler.getDevice()).getMotion();
        result.put("course", value.course);
        result.put("speed", value.speed);
        return result;
    }

    public static Map<String, Object> getMotion(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            return ((BrickletGPSActions) actions).getMotion();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }

    @RuleAction(label = "Get Date Time")
    public @ActionOutput(name = "date", type="long")
           @ActionOutput(name = "time", type="long")
           Map<String, Object> getDateTime(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPS.DateTime value = ((BrickletGPS)this.handler.getDevice()).getDateTime();
        result.put("date", value.date);
        result.put("time", value.time);
        return result;
    }

    public static Map<String, Object> getDateTime(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            return ((BrickletGPSActions) actions).getDateTime();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }

    @RuleAction(label = "Restart")
    public void restart(
            @ActionInput(name = "restartType") short restartType) throws TinkerforgeException {
        ((BrickletGPS)this.handler.getDevice()).restart(restartType);
    }

    public static void restart(@Nullable ThingActions actions, short restartType) throws TinkerforgeException {
        if (actions instanceof BrickletGPSActions) {
            ((BrickletGPSActions) actions).restart(restartType);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSActions class.");
        }
    }
}
