package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletGPSV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Coordinates")
    public @ActionOutput(name = "latitude", type="long")
           @ActionOutput(name = "ns", type="char")
           @ActionOutput(name = "longitude", type="long")
           @ActionOutput(name = "ew", type="char")
           Map<String, Object> getCoordinates(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.Coordinates value = ((BrickletGPSV2)this.handler.getDevice()).getCoordinates();
        result.put("latitude", value.latitude);
        result.put("ns", value.ns);
        result.put("longitude", value.longitude);
        result.put("ew", value.ew);
        return result;
    }

    public static Map<String, Object> getCoordinates(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getCoordinates();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Status")
    public @ActionOutput(name = "hasFix", type="boolean")
           @ActionOutput(name = "satellitesView", type="int")
           Map<String, Object> getStatus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.Status value = ((BrickletGPSV2)this.handler.getDevice()).getStatus();
        result.put("hasFix", value.hasFix);
        result.put("satellitesView", value.satellitesView);
        return result;
    }

    public static Map<String, Object> getStatus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getStatus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Altitude")
    public @ActionOutput(name = "altitude", type="int")
           @ActionOutput(name = "geoidalSeparation", type="int")
           Map<String, Object> getAltitude(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.Altitude value = ((BrickletGPSV2)this.handler.getDevice()).getAltitude();
        result.put("altitude", value.altitude);
        result.put("geoidalSeparation", value.geoidalSeparation);
        return result;
    }

    public static Map<String, Object> getAltitude(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getAltitude();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Motion")
    public @ActionOutput(name = "course", type="long")
           @ActionOutput(name = "speed", type="long")
           Map<String, Object> getMotion(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.Motion value = ((BrickletGPSV2)this.handler.getDevice()).getMotion();
        result.put("course", value.course);
        result.put("speed", value.speed);
        return result;
    }

    public static Map<String, Object> getMotion(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getMotion();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Date Time")
    public @ActionOutput(name = "date", type="long")
           @ActionOutput(name = "time", type="long")
           Map<String, Object> getDateTime(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.DateTime value = ((BrickletGPSV2)this.handler.getDevice()).getDateTime();
        result.put("date", value.date);
        result.put("time", value.time);
        return result;
    }

    public static Map<String, Object> getDateTime(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getDateTime();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Satellite System Status")
    public @ActionOutput(name = "satelliteNumbers", type="int[]")
           @ActionOutput(name = "fix", type="int")
           @ActionOutput(name = "pdop", type="int")
           @ActionOutput(name = "hdop", type="int")
           @ActionOutput(name = "vdop", type="int")
           Map<String, Object> getSatelliteSystemStatus(
            @ActionInput(name = "satelliteSystem") int satelliteSystem) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.SatelliteSystemStatus value = ((BrickletGPSV2)this.handler.getDevice()).getSatelliteSystemStatus(satelliteSystem);
        result.put("satelliteNumbers", value.satelliteNumbers);
        result.put("fix", value.fix);
        result.put("pdop", value.pdop);
        result.put("hdop", value.hdop);
        result.put("vdop", value.vdop);
        return result;
    }

    public static Map<String, Object> getSatelliteSystemStatus(@Nullable ThingActions actions, int satelliteSystem) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getSatelliteSystemStatus(satelliteSystem);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Satellite Status")
    public @ActionOutput(name = "elevation", type="int")
           @ActionOutput(name = "azimuth", type="int")
           @ActionOutput(name = "snr", type="int")
           Map<String, Object> getSatelliteStatus(
            @ActionInput(name = "satelliteSystem") int satelliteSystem,
            @ActionInput(name = "satelliteNumber") int satelliteNumber) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletGPSV2.SatelliteStatus value = ((BrickletGPSV2)this.handler.getDevice()).getSatelliteStatus(satelliteSystem, satelliteNumber);
        result.put("elevation", value.elevation);
        result.put("azimuth", value.azimuth);
        result.put("snr", value.snr);
        return result;
    }

    public static Map<String, Object> getSatelliteStatus(@Nullable ThingActions actions, int satelliteSystem, int satelliteNumber) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getSatelliteStatus(satelliteSystem, satelliteNumber);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Restart")
    public void restart(
            @ActionInput(name = "restartType") int restartType) throws TinkerforgeException {
        ((BrickletGPSV2)this.handler.getDevice()).restart(restartType);
    }

    public static void restart(@Nullable ThingActions actions, int restartType) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            ((BrickletGPSV2Actions) actions).restart(restartType);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get Fix LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getFixLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletGPSV2)this.handler.getDevice()).getFixLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getFixLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getFixLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }

    @RuleAction(label = "Get SBAS Config")
    public @ActionOutput(name = "sbasConfig", type="int")
           Map<String, Object> getSBASConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletGPSV2)this.handler.getDevice()).getSBASConfig();
        result.put("sbasConfig", value);
        return result;
    }

    public static Map<String, Object> getSBASConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletGPSV2Actions) {
            return ((BrickletGPSV2Actions) actions).getSBASConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletGPSV2Actions class.");
        }
    }
}
