package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletHallEffectActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Value")
    public @ActionOutput(name = "value", type="boolean")
           Map<String, Object> getValue(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletHallEffect)this.handler.getDevice()).getValue();
        result.put("value", value);
        return result;
    }

    public static Map<String, Object> getValue(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHallEffectActions) {
            return ((BrickletHallEffectActions) actions).getValue();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHallEffectActions class.");
        }
    }

    @RuleAction(label = "Get Edge Count")
    public @ActionOutput(name = "count", type="long")
           Map<String, Object> getEdgeCount(
            @ActionInput(name = "resetCounter") boolean resetCounter) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletHallEffect)this.handler.getDevice()).getEdgeCount(resetCounter);
        result.put("count", value);
        return result;
    }

    public static Map<String, Object> getEdgeCount(@Nullable ThingActions actions, boolean resetCounter) throws TinkerforgeException {
        if (actions instanceof BrickletHallEffectActions) {
            return ((BrickletHallEffectActions) actions).getEdgeCount(resetCounter);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHallEffectActions class.");
        }
    }

    @RuleAction(label = "Get Edge Count Config")
    public @ActionOutput(name = "edgeType", type="short")
           @ActionOutput(name = "debounce", type="short")
           Map<String, Object> getEdgeCountConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletHallEffect.EdgeCountConfig value = ((BrickletHallEffect)this.handler.getDevice()).getEdgeCountConfig();
        result.put("edgeType", value.edgeType);
        result.put("debounce", value.debounce);
        return result;
    }

    public static Map<String, Object> getEdgeCountConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHallEffectActions) {
            return ((BrickletHallEffectActions) actions).getEdgeCountConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHallEffectActions class.");
        }
    }
}
