package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletHumidityV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Humidity")
    public @ActionOutput(name = "humidity", type="int")
           Map<String, Object> getHumidity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletHumidityV2)this.handler.getDevice()).getHumidity();
        result.put("humidity", value);
        return result;
    }

    public static Map<String, Object> getHumidity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHumidityV2Actions) {
            return ((BrickletHumidityV2Actions) actions).getHumidity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHumidityV2Actions class.");
        }
    }

    @RuleAction(label = "Get Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletHumidityV2)this.handler.getDevice()).getTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHumidityV2Actions) {
            return ((BrickletHumidityV2Actions) actions).getTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHumidityV2Actions class.");
        }
    }

    @RuleAction(label = "Get Heater Configuration")
    public @ActionOutput(name = "heaterConfig", type="int")
           Map<String, Object> getHeaterConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletHumidityV2)this.handler.getDevice()).getHeaterConfiguration();
        result.put("heaterConfig", value);
        return result;
    }

    public static Map<String, Object> getHeaterConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHumidityV2Actions) {
            return ((BrickletHumidityV2Actions) actions).getHeaterConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHumidityV2Actions class.");
        }
    }

    @RuleAction(label = "Get Moving Average Configuration")
    public @ActionOutput(name = "movingAverageLengthHumidity", type="int")
           @ActionOutput(name = "movingAverageLengthTemperature", type="int")
           Map<String, Object> getMovingAverageConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletHumidityV2.MovingAverageConfiguration value = ((BrickletHumidityV2)this.handler.getDevice()).getMovingAverageConfiguration();
        result.put("movingAverageLengthHumidity", value.movingAverageLengthHumidity);
        result.put("movingAverageLengthTemperature", value.movingAverageLengthTemperature);
        return result;
    }

    public static Map<String, Object> getMovingAverageConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHumidityV2Actions) {
            return ((BrickletHumidityV2Actions) actions).getMovingAverageConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHumidityV2Actions class.");
        }
    }

    @RuleAction(label = "Get Samples Per Second")
    public @ActionOutput(name = "sps", type="int")
           Map<String, Object> getSamplesPerSecond(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletHumidityV2)this.handler.getDevice()).getSamplesPerSecond();
        result.put("sps", value);
        return result;
    }

    public static Map<String, Object> getSamplesPerSecond(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletHumidityV2Actions) {
            return ((BrickletHumidityV2Actions) actions).getSamplesPerSecond();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletHumidityV2Actions class.");
        }
    }
}
