package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletIndustrialAnalogOutV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Enabled")
    public @ActionOutput(name = "enabled", type="boolean")
           Map<String, Object> getEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getEnabled();
        result.put("enabled", value);
        return result;
    }

    public static Map<String, Object> getEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }

    @RuleAction(label = "Get Voltage")
    public @ActionOutput(name = "voltage", type="int")
           Map<String, Object> getVoltage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getVoltage();
        result.put("voltage", value);
        return result;
    }

    public static Map<String, Object> getVoltage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getVoltage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }

    @RuleAction(label = "Get Current")
    public @ActionOutput(name = "current", type="int")
           Map<String, Object> getCurrent(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getCurrent();
        result.put("current", value);
        return result;
    }

    public static Map<String, Object> getCurrent(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getCurrent();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "voltageRange", type="int")
           @ActionOutput(name = "currentRange", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletIndustrialAnalogOutV2.Configuration value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getConfiguration();
        result.put("voltageRange", value.voltageRange);
        result.put("currentRange", value.currentRange);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }

    @RuleAction(label = "Get Out LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getOutLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getOutLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getOutLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getOutLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }

    @RuleAction(label = "Get Out LED Status Config")
    public @ActionOutput(name = "min", type="int")
           @ActionOutput(name = "max", type="int")
           @ActionOutput(name = "config", type="int")
           Map<String, Object> getOutLEDStatusConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletIndustrialAnalogOutV2.OutLEDStatusConfig value = ((BrickletIndustrialAnalogOutV2)this.handler.getDevice()).getOutLEDStatusConfig();
        result.put("min", value.min);
        result.put("max", value.max);
        result.put("config", value.config);
        return result;
    }

    public static Map<String, Object> getOutLEDStatusConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialAnalogOutV2Actions) {
            return ((BrickletIndustrialAnalogOutV2Actions) actions).getOutLEDStatusConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialAnalogOutV2Actions class.");
        }
    }
}
