package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletIndustrialCounterActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Counter")
    public @ActionOutput(name = "counter", type="long")
           Map<String, Object> getCounter(
            @ActionInput(name = "channel") int channel) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long value = ((BrickletIndustrialCounter)this.handler.getDevice()).getCounter(channel);
        result.put("counter", value);
        return result;
    }

    public static Map<String, Object> getCounter(@Nullable ThingActions actions, int channel) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getCounter(channel);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get All Counter")
    public @ActionOutput(name = "counter", type="long[]")
           Map<String, Object> getAllCounter(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        long[] value = ((BrickletIndustrialCounter)this.handler.getDevice()).getAllCounter();
        result.put("counter", value);
        return result;
    }

    public static Map<String, Object> getAllCounter(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getAllCounter();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Set Counter")
    public void setCounter(
            @ActionInput(name = "channel") int channel,
            @ActionInput(name = "counter") long counter) throws TinkerforgeException {
        ((BrickletIndustrialCounter)this.handler.getDevice()).setCounter(channel, counter);
    }

    public static void setCounter(@Nullable ThingActions actions, int channel, long counter) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            ((BrickletIndustrialCounterActions) actions).setCounter(channel, counter);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Set All Counter")
    public void setAllCounter(
            @ActionInput(name = "counter") long[] counter) throws TinkerforgeException {
        ((BrickletIndustrialCounter)this.handler.getDevice()).setAllCounter(counter);
    }

    public static void setAllCounter(@Nullable ThingActions actions, long[] counter) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            ((BrickletIndustrialCounterActions) actions).setAllCounter(counter);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get Signal Data")
    public @ActionOutput(name = "dutyCycle", type="int")
           @ActionOutput(name = "period", type="long")
           @ActionOutput(name = "frequency", type="long")
           @ActionOutput(name = "value", type="boolean")
           Map<String, Object> getSignalData(
            @ActionInput(name = "channel") int channel) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletIndustrialCounter.SignalData value = ((BrickletIndustrialCounter)this.handler.getDevice()).getSignalData(channel);
        result.put("dutyCycle", value.dutyCycle);
        result.put("period", value.period);
        result.put("frequency", value.frequency);
        result.put("value", value.value);
        return result;
    }

    public static Map<String, Object> getSignalData(@Nullable ThingActions actions, int channel) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getSignalData(channel);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get All Signal Data")
    public @ActionOutput(name = "dutyCycle", type="int[]")
           @ActionOutput(name = "period", type="long[]")
           @ActionOutput(name = "frequency", type="long[]")
           @ActionOutput(name = "value", type="boolean[]")
           Map<String, Object> getAllSignalData(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletIndustrialCounter.AllSignalData value = ((BrickletIndustrialCounter)this.handler.getDevice()).getAllSignalData();
        result.put("dutyCycle", value.dutyCycle);
        result.put("period", value.period);
        result.put("frequency", value.frequency);
        result.put("value", value.value);
        return result;
    }

    public static Map<String, Object> getAllSignalData(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getAllSignalData();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get Counter Active")
    public @ActionOutput(name = "active", type="boolean")
           Map<String, Object> getCounterActive(
            @ActionInput(name = "channel") int channel) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletIndustrialCounter)this.handler.getDevice()).getCounterActive(channel);
        result.put("active", value);
        return result;
    }

    public static Map<String, Object> getCounterActive(@Nullable ThingActions actions, int channel) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getCounterActive(channel);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get All Counter Active")
    public @ActionOutput(name = "active", type="boolean[]")
           Map<String, Object> getAllCounterActive(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean[] value = ((BrickletIndustrialCounter)this.handler.getDevice()).getAllCounterActive();
        result.put("active", value);
        return result;
    }

    public static Map<String, Object> getAllCounterActive(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getAllCounterActive();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get Counter Configuration")
    public @ActionOutput(name = "countEdge", type="int")
           @ActionOutput(name = "countDirection", type="int")
           @ActionOutput(name = "dutyCyclePrescaler", type="int")
           @ActionOutput(name = "frequencyIntegrationTime", type="int")
           Map<String, Object> getCounterConfiguration(
            @ActionInput(name = "channel") int channel) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletIndustrialCounter.CounterConfiguration value = ((BrickletIndustrialCounter)this.handler.getDevice()).getCounterConfiguration(channel);
        result.put("countEdge", value.countEdge);
        result.put("countDirection", value.countDirection);
        result.put("dutyCyclePrescaler", value.dutyCyclePrescaler);
        result.put("frequencyIntegrationTime", value.frequencyIntegrationTime);
        return result;
    }

    public static Map<String, Object> getCounterConfiguration(@Nullable ThingActions actions, int channel) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getCounterConfiguration(channel);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }

    @RuleAction(label = "Get Channel LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getChannelLEDConfig(
            @ActionInput(name = "channel") int channel) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletIndustrialCounter)this.handler.getDevice()).getChannelLEDConfig(channel);
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getChannelLEDConfig(@Nullable ThingActions actions, int channel) throws TinkerforgeException {
        if (actions instanceof BrickletIndustrialCounterActions) {
            return ((BrickletIndustrialCounterActions) actions).getChannelLEDConfig(channel);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletIndustrialCounterActions class.");
        }
    }
}
