package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletJoystickActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Position")
    public @ActionOutput(name = "x", type="short")
           @ActionOutput(name = "y", type="short")
           Map<String, Object> getPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletJoystick.Position value = ((BrickletJoystick)this.handler.getDevice()).getPosition();
        result.put("x", value.x);
        result.put("y", value.y);
        return result;
    }

    public static Map<String, Object> getPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletJoystickActions) {
            return ((BrickletJoystickActions) actions).getPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletJoystickActions class.");
        }
    }

    @RuleAction(label = "Is Pressed")
    public @ActionOutput(name = "pressed", type="boolean")
           Map<String, Object> isPressed(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletJoystick)this.handler.getDevice()).isPressed();
        result.put("pressed", value);
        return result;
    }

    public static Map<String, Object> isPressed(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletJoystickActions) {
            return ((BrickletJoystickActions) actions).isPressed();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletJoystickActions class.");
        }
    }

    @RuleAction(label = "Get Analog Value")
    public @ActionOutput(name = "x", type="int")
           @ActionOutput(name = "y", type="int")
           Map<String, Object> getAnalogValue(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletJoystick.AnalogValue value = ((BrickletJoystick)this.handler.getDevice()).getAnalogValue();
        result.put("x", value.x);
        result.put("y", value.y);
        return result;
    }

    public static Map<String, Object> getAnalogValue(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletJoystickActions) {
            return ((BrickletJoystickActions) actions).getAnalogValue();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletJoystickActions class.");
        }
    }
}
