package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletLaserRangeFinderActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Distance")
    public @ActionOutput(name = "distance", type="int")
           Map<String, Object> getDistance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getDistance();
        result.put("distance", value);
        return result;
    }

    public static Map<String, Object> getDistance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getDistance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Get Velocity")
    public @ActionOutput(name = "velocity", type="short")
           Map<String, Object> getVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Get Mode")
    public @ActionOutput(name = "mode", type="short")
           Map<String, Object> getMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> getMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Is Laser Enabled")
    public @ActionOutput(name = "laserEnabled", type="boolean")
           Map<String, Object> isLaserEnabled(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletLaserRangeFinder)this.handler.getDevice()).isLaserEnabled();
        result.put("laserEnabled", value);
        return result;
    }

    public static Map<String, Object> isLaserEnabled(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).isLaserEnabled();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "acquisitionCount", type="short")
           @ActionOutput(name = "enableQuickTermination", type="boolean")
           @ActionOutput(name = "thresholdValue", type="short")
           @ActionOutput(name = "measurementFrequency", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLaserRangeFinder.Configuration value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getConfiguration();
        result.put("acquisitionCount", value.acquisitionCount);
        result.put("enableQuickTermination", value.enableQuickTermination);
        result.put("thresholdValue", value.thresholdValue);
        result.put("measurementFrequency", value.measurementFrequency);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Get Moving Average")
    public @ActionOutput(name = "distanceAverageLength", type="short")
           @ActionOutput(name = "velocityAverageLength", type="short")
           Map<String, Object> getMovingAverage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLaserRangeFinder.MovingAverage value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getMovingAverage();
        result.put("distanceAverageLength", value.distanceAverageLength);
        result.put("velocityAverageLength", value.velocityAverageLength);
        return result;
    }

    public static Map<String, Object> getMovingAverage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getMovingAverage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }

    @RuleAction(label = "Get Sensor Hardware Version")
    public @ActionOutput(name = "version", type="short")
           Map<String, Object> getSensorHardwareVersion(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletLaserRangeFinder)this.handler.getDevice()).getSensorHardwareVersion();
        result.put("version", value);
        return result;
    }

    public static Map<String, Object> getSensorHardwareVersion(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderActions) {
            return ((BrickletLaserRangeFinderActions) actions).getSensorHardwareVersion();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderActions class.");
        }
    }
}
