package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletLaserRangeFinderV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Distance")
    public @ActionOutput(name = "distance", type="int")
           Map<String, Object> getDistance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getDistance();
        result.put("distance", value);
        return result;
    }

    public static Map<String, Object> getDistance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getDistance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Velocity")
    public @ActionOutput(name = "velocity", type="int")
           Map<String, Object> getVelocity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getVelocity();
        result.put("velocity", value);
        return result;
    }

    public static Map<String, Object> getVelocity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getVelocity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Enable")
    public @ActionOutput(name = "enable", type="boolean")
           Map<String, Object> getEnable(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getEnable();
        result.put("enable", value);
        return result;
    }

    public static Map<String, Object> getEnable(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getEnable();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "acquisitionCount", type="int")
           @ActionOutput(name = "enableQuickTermination", type="boolean")
           @ActionOutput(name = "thresholdValue", type="int")
           @ActionOutput(name = "measurementFrequency", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLaserRangeFinderV2.Configuration value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getConfiguration();
        result.put("acquisitionCount", value.acquisitionCount);
        result.put("enableQuickTermination", value.enableQuickTermination);
        result.put("thresholdValue", value.thresholdValue);
        result.put("measurementFrequency", value.measurementFrequency);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Distance LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getDistanceLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getDistanceLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getDistanceLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getDistanceLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Moving Average")
    public @ActionOutput(name = "distanceAverageLength", type="int")
           @ActionOutput(name = "velocityAverageLength", type="int")
           Map<String, Object> getMovingAverage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLaserRangeFinderV2.MovingAverage value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getMovingAverage();
        result.put("distanceAverageLength", value.distanceAverageLength);
        result.put("velocityAverageLength", value.velocityAverageLength);
        return result;
    }

    public static Map<String, Object> getMovingAverage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getMovingAverage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }

    @RuleAction(label = "Get Offset Calibration")
    public @ActionOutput(name = "offset", type="int")
           Map<String, Object> getOffsetCalibration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLaserRangeFinderV2)this.handler.getDevice()).getOffsetCalibration();
        result.put("offset", value);
        return result;
    }

    public static Map<String, Object> getOffsetCalibration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLaserRangeFinderV2Actions) {
            return ((BrickletLaserRangeFinderV2Actions) actions).getOffsetCalibration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLaserRangeFinderV2Actions class.");
        }
    }
}
