package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletLoadCellActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Weight")
    public @ActionOutput(name = "weight", type="int")
           Map<String, Object> getWeight(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLoadCell)this.handler.getDevice()).getWeight();
        result.put("weight", value);
        return result;
    }

    public static Map<String, Object> getWeight(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellActions) {
            return ((BrickletLoadCellActions) actions).getWeight();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellActions class.");
        }
    }

    @RuleAction(label = "Tare")
    public void tare(
            ) throws TinkerforgeException {
        ((BrickletLoadCell)this.handler.getDevice()).tare();
    }

    public static void tare(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellActions) {
            ((BrickletLoadCellActions) actions).tare();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellActions class.");
        }
    }

    @RuleAction(label = "Get Moving Average")
    public @ActionOutput(name = "average", type="short")
           Map<String, Object> getMovingAverage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletLoadCell)this.handler.getDevice()).getMovingAverage();
        result.put("average", value);
        return result;
    }

    public static Map<String, Object> getMovingAverage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellActions) {
            return ((BrickletLoadCellActions) actions).getMovingAverage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellActions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "rate", type="short")
           @ActionOutput(name = "gain", type="short")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLoadCell.Configuration value = ((BrickletLoadCell)this.handler.getDevice()).getConfiguration();
        result.put("rate", value.rate);
        result.put("gain", value.gain);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellActions) {
            return ((BrickletLoadCellActions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellActions class.");
        }
    }

    @RuleAction(label = "Is LED On")
    public @ActionOutput(name = "on", type="boolean")
           Map<String, Object> isLEDOn(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletLoadCell)this.handler.getDevice()).isLEDOn();
        result.put("on", value);
        return result;
    }

    public static Map<String, Object> isLEDOn(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellActions) {
            return ((BrickletLoadCellActions) actions).isLEDOn();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellActions class.");
        }
    }
}
