package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletLoadCellV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Weight")
    public @ActionOutput(name = "weight", type="int")
           Map<String, Object> getWeight(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLoadCellV2)this.handler.getDevice()).getWeight();
        result.put("weight", value);
        return result;
    }

    public static Map<String, Object> getWeight(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellV2Actions) {
            return ((BrickletLoadCellV2Actions) actions).getWeight();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellV2Actions class.");
        }
    }

    @RuleAction(label = "Get Info LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getInfoLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLoadCellV2)this.handler.getDevice()).getInfoLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getInfoLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellV2Actions) {
            return ((BrickletLoadCellV2Actions) actions).getInfoLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellV2Actions class.");
        }
    }

    @RuleAction(label = "Tare")
    public void tare(
            ) throws TinkerforgeException {
        ((BrickletLoadCellV2)this.handler.getDevice()).tare();
    }

    public static void tare(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellV2Actions) {
            ((BrickletLoadCellV2Actions) actions).tare();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellV2Actions class.");
        }
    }

    @RuleAction(label = "Get Moving Average")
    public @ActionOutput(name = "average", type="int")
           Map<String, Object> getMovingAverage(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletLoadCellV2)this.handler.getDevice()).getMovingAverage();
        result.put("average", value);
        return result;
    }

    public static Map<String, Object> getMovingAverage(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellV2Actions) {
            return ((BrickletLoadCellV2Actions) actions).getMovingAverage();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellV2Actions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "rate", type="int")
           @ActionOutput(name = "gain", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletLoadCellV2.Configuration value = ((BrickletLoadCellV2)this.handler.getDevice()).getConfiguration();
        result.put("rate", value.rate);
        result.put("gain", value.gain);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletLoadCellV2Actions) {
            return ((BrickletLoadCellV2Actions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletLoadCellV2Actions class.");
        }
    }
}
