package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletMotorizedLinearPotiActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Position")
    public @ActionOutput(name = "position", type="int")
           Map<String, Object> getPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletMotorizedLinearPoti)this.handler.getDevice()).getPosition();
        result.put("position", value);
        return result;
    }

    public static Map<String, Object> getPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletMotorizedLinearPotiActions) {
            return ((BrickletMotorizedLinearPotiActions) actions).getPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletMotorizedLinearPotiActions class.");
        }
    }

    @RuleAction(label = "Get Motor Position")
    public @ActionOutput(name = "position", type="int")
           @ActionOutput(name = "driveMode", type="int")
           @ActionOutput(name = "holdPosition", type="boolean")
           @ActionOutput(name = "positionReached", type="boolean")
           Map<String, Object> getMotorPosition(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletMotorizedLinearPoti.MotorPosition value = ((BrickletMotorizedLinearPoti)this.handler.getDevice()).getMotorPosition();
        result.put("position", value.position);
        result.put("driveMode", value.driveMode);
        result.put("holdPosition", value.holdPosition);
        result.put("positionReached", value.positionReached);
        return result;
    }

    public static Map<String, Object> getMotorPosition(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletMotorizedLinearPotiActions) {
            return ((BrickletMotorizedLinearPotiActions) actions).getMotorPosition();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletMotorizedLinearPotiActions class.");
        }
    }
}
