package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletOLED128x64V2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Write Pixels")
    public void writePixels(
            @ActionInput(name = "xStart") int xStart,
            @ActionInput(name = "yStart") int yStart,
            @ActionInput(name = "xEnd") int xEnd,
            @ActionInput(name = "yEnd") int yEnd,
            @ActionInput(name = "pixels") boolean[] pixels) throws TinkerforgeException {
        ((BrickletOLED128x64V2)this.handler.getDevice()).writePixels(xStart, yStart, xEnd, yEnd, pixels);
    }

    public static void writePixels(@Nullable ThingActions actions, int xStart, int yStart, int xEnd, int yEnd, boolean[] pixels) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            ((BrickletOLED128x64V2Actions) actions).writePixels(xStart, yStart, xEnd, yEnd, pixels);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }

    @RuleAction(label = "Read Pixels")
    public @ActionOutput(name = "pixels", type="boolean[]")
           Map<String, Object> readPixels(
            @ActionInput(name = "xStart") int xStart,
            @ActionInput(name = "yStart") int yStart,
            @ActionInput(name = "xEnd") int xEnd,
            @ActionInput(name = "yEnd") int yEnd) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean[] value = ((BrickletOLED128x64V2)this.handler.getDevice()).readPixels(xStart, yStart, xEnd, yEnd);
        result.put("pixels", value);
        return result;
    }

    public static Map<String, Object> readPixels(@Nullable ThingActions actions, int xStart, int yStart, int xEnd, int yEnd) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            return ((BrickletOLED128x64V2Actions) actions).readPixels(xStart, yStart, xEnd, yEnd);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }

    @RuleAction(label = "Clear Display")
    public void clearDisplay(
            ) throws TinkerforgeException {
        ((BrickletOLED128x64V2)this.handler.getDevice()).clearDisplay();
    }

    public static void clearDisplay(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            ((BrickletOLED128x64V2Actions) actions).clearDisplay();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }

    @RuleAction(label = "Draw Buffered Frame")
    public void drawBufferedFrame(
            @ActionInput(name = "forceCompleteRedraw") boolean forceCompleteRedraw) throws TinkerforgeException {
        ((BrickletOLED128x64V2)this.handler.getDevice()).drawBufferedFrame(forceCompleteRedraw);
    }

    public static void drawBufferedFrame(@Nullable ThingActions actions, boolean forceCompleteRedraw) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            ((BrickletOLED128x64V2Actions) actions).drawBufferedFrame(forceCompleteRedraw);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }

    @RuleAction(label = "Write Line")
    public void writeLine(
            @ActionInput(name = "line") int line,
            @ActionInput(name = "position") int position,
            @ActionInput(name = "text") String text) throws TinkerforgeException {
        ((BrickletOLED128x64V2)this.handler.getDevice()).writeLine(line, position, text);
    }

    public static void writeLine(@Nullable ThingActions actions, int line, int position, String text) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            ((BrickletOLED128x64V2Actions) actions).writeLine(line, position, text);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }

    @RuleAction(label = "Get Display Configuration")
    public @ActionOutput(name = "contrast", type="int")
           @ActionOutput(name = "invert", type="boolean")
           @ActionOutput(name = "automaticDraw", type="boolean")
           Map<String, Object> getDisplayConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletOLED128x64V2.DisplayConfiguration value = ((BrickletOLED128x64V2)this.handler.getDevice()).getDisplayConfiguration();
        result.put("contrast", value.contrast);
        result.put("invert", value.invert);
        result.put("automaticDraw", value.automaticDraw);
        return result;
    }

    public static Map<String, Object> getDisplayConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOLED128x64V2Actions) {
            return ((BrickletOLED128x64V2Actions) actions).getDisplayConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOLED128x64V2Actions class.");
        }
    }
}
