package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletOneWireActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Search Bus")
    public @ActionOutput(name = "identifier", type="long[]")
           @ActionOutput(name = "status", type="int")
           Map<String, Object> searchBus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletOneWire.SearchBus value = ((BrickletOneWire)this.handler.getDevice()).searchBus();
        result.put("identifier", value.identifier);
        result.put("status", value.status);
        return result;
    }

    public static Map<String, Object> searchBus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).searchBus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }

    @RuleAction(label = "Reset Bus")
    public @ActionOutput(name = "status", type="int")
           Map<String, Object> resetBus(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletOneWire)this.handler.getDevice()).resetBus();
        result.put("status", value);
        return result;
    }

    public static Map<String, Object> resetBus(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).resetBus();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }

    @RuleAction(label = "Write")
    public @ActionOutput(name = "status", type="int")
           Map<String, Object> write(
            @ActionInput(name = "data") int data) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletOneWire)this.handler.getDevice()).write(data);
        result.put("status", value);
        return result;
    }

    public static Map<String, Object> write(@Nullable ThingActions actions, int data) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).write(data);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }

    @RuleAction(label = "Read")
    public @ActionOutput(name = "data", type="int")
           @ActionOutput(name = "status", type="int")
           Map<String, Object> read(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletOneWire.Read value = ((BrickletOneWire)this.handler.getDevice()).read();
        result.put("data", value.data);
        result.put("status", value.status);
        return result;
    }

    public static Map<String, Object> read(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).read();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }

    @RuleAction(label = "Write Command")
    public @ActionOutput(name = "status", type="int")
           Map<String, Object> writeCommand(
            @ActionInput(name = "identifier") long identifier,
            @ActionInput(name = "command") int command) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletOneWire)this.handler.getDevice()).writeCommand(identifier, command);
        result.put("status", value);
        return result;
    }

    public static Map<String, Object> writeCommand(@Nullable ThingActions actions, long identifier, int command) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).writeCommand(identifier, command);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }

    @RuleAction(label = "Get Communication LED Config")
    public @ActionOutput(name = "config", type="int")
           Map<String, Object> getCommunicationLEDConfig(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletOneWire)this.handler.getDevice()).getCommunicationLEDConfig();
        result.put("config", value);
        return result;
    }

    public static Map<String, Object> getCommunicationLEDConfig(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletOneWireActions) {
            return ((BrickletOneWireActions) actions).getCommunicationLEDConfig();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletOneWireActions class.");
        }
    }
}
