package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletPTCActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletPTC)this.handler.getDevice()).getTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPTCActions) {
            return ((BrickletPTCActions) actions).getTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPTCActions class.");
        }
    }

    @RuleAction(label = "Is Sensor Connected")
    public @ActionOutput(name = "connected", type="boolean")
           Map<String, Object> isSensorConnected(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        boolean value = ((BrickletPTC)this.handler.getDevice()).isSensorConnected();
        result.put("connected", value);
        return result;
    }

    public static Map<String, Object> isSensorConnected(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPTCActions) {
            return ((BrickletPTCActions) actions).isSensorConnected();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPTCActions class.");
        }
    }

    @RuleAction(label = "Get Wire Mode")
    public @ActionOutput(name = "mode", type="short")
           Map<String, Object> getWireMode(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletPTC)this.handler.getDevice()).getWireMode();
        result.put("mode", value);
        return result;
    }

    public static Map<String, Object> getWireMode(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPTCActions) {
            return ((BrickletPTCActions) actions).getWireMode();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPTCActions class.");
        }
    }

    @RuleAction(label = "Get Resistance")
    public @ActionOutput(name = "resistance", type="int")
           Map<String, Object> getResistance(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletPTC)this.handler.getDevice()).getResistance();
        result.put("resistance", value);
        return result;
    }

    public static Map<String, Object> getResistance(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPTCActions) {
            return ((BrickletPTCActions) actions).getResistance();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPTCActions class.");
        }
    }

    @RuleAction(label = "Get Noise Rejection Filter")
    public @ActionOutput(name = "filter", type="short")
           Map<String, Object> getNoiseRejectionFilter(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        short value = ((BrickletPTC)this.handler.getDevice()).getNoiseRejectionFilter();
        result.put("filter", value);
        return result;
    }

    public static Map<String, Object> getNoiseRejectionFilter(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPTCActions) {
            return ((BrickletPTCActions) actions).getNoiseRejectionFilter();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPTCActions class.");
        }
    }
}
