package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletPiezoSpeakerV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Set Beep")
    public void setBeep(
            @ActionInput(name = "frequency") int frequency,
            @ActionInput(name = "volume") int volume,
            @ActionInput(name = "duration") long duration) throws TinkerforgeException {
        ((BrickletPiezoSpeakerV2)this.handler.getDevice()).setBeep(frequency, volume, duration);
    }

    public static void setBeep(@Nullable ThingActions actions, int frequency, int volume, long duration) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            ((BrickletPiezoSpeakerV2Actions) actions).setBeep(frequency, volume, duration);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Beep")
    public @ActionOutput(name = "frequency", type="int")
           @ActionOutput(name = "volume", type="int")
           @ActionOutput(name = "duration", type="long")
           @ActionOutput(name = "durationRemaining", type="long")
           Map<String, Object> getBeep(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletPiezoSpeakerV2.Beep value = ((BrickletPiezoSpeakerV2)this.handler.getDevice()).getBeep();
        result.put("frequency", value.frequency);
        result.put("volume", value.volume);
        result.put("duration", value.duration);
        result.put("durationRemaining", value.durationRemaining);
        return result;
    }

    public static Map<String, Object> getBeep(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            return ((BrickletPiezoSpeakerV2Actions) actions).getBeep();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }

    @RuleAction(label = "Set Alarm")
    public void setAlarm(
            @ActionInput(name = "startFrequency") int startFrequency,
            @ActionInput(name = "endFrequency") int endFrequency,
            @ActionInput(name = "stepSize") int stepSize,
            @ActionInput(name = "stepDelay") int stepDelay,
            @ActionInput(name = "volume") int volume,
            @ActionInput(name = "duration") long duration) throws TinkerforgeException {
        ((BrickletPiezoSpeakerV2)this.handler.getDevice()).setAlarm(startFrequency, endFrequency, stepSize, stepDelay, volume, duration);
    }

    public static void setAlarm(@Nullable ThingActions actions, int startFrequency, int endFrequency, int stepSize, int stepDelay, int volume, long duration) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            ((BrickletPiezoSpeakerV2Actions) actions).setAlarm(startFrequency, endFrequency, stepSize, stepDelay, volume, duration);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }

    @RuleAction(label = "Get Alarm")
    public @ActionOutput(name = "startFrequency", type="int")
           @ActionOutput(name = "endFrequency", type="int")
           @ActionOutput(name = "stepSize", type="int")
           @ActionOutput(name = "stepDelay", type="int")
           @ActionOutput(name = "volume", type="int")
           @ActionOutput(name = "duration", type="long")
           @ActionOutput(name = "durationRemaining", type="long")
           @ActionOutput(name = "currentFrequency", type="int")
           Map<String, Object> getAlarm(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletPiezoSpeakerV2.Alarm value = ((BrickletPiezoSpeakerV2)this.handler.getDevice()).getAlarm();
        result.put("startFrequency", value.startFrequency);
        result.put("endFrequency", value.endFrequency);
        result.put("stepSize", value.stepSize);
        result.put("stepDelay", value.stepDelay);
        result.put("volume", value.volume);
        result.put("duration", value.duration);
        result.put("durationRemaining", value.durationRemaining);
        result.put("currentFrequency", value.currentFrequency);
        return result;
    }

    public static Map<String, Object> getAlarm(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            return ((BrickletPiezoSpeakerV2Actions) actions).getAlarm();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }

    @RuleAction(label = "Update Volume")
    public void updateVolume(
            @ActionInput(name = "volume") int volume) throws TinkerforgeException {
        ((BrickletPiezoSpeakerV2)this.handler.getDevice()).updateVolume(volume);
    }

    public static void updateVolume(@Nullable ThingActions actions, int volume) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            ((BrickletPiezoSpeakerV2Actions) actions).updateVolume(volume);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }

    @RuleAction(label = "Update Frequency")
    public void updateFrequency(
            @ActionInput(name = "frequency") int frequency) throws TinkerforgeException {
        ((BrickletPiezoSpeakerV2)this.handler.getDevice()).updateFrequency(frequency);
    }

    public static void updateFrequency(@Nullable ThingActions actions, int frequency) throws TinkerforgeException {
        if (actions instanceof BrickletPiezoSpeakerV2Actions) {
            ((BrickletPiezoSpeakerV2Actions) actions).updateFrequency(frequency);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletPiezoSpeakerV2Actions class.");
        }
    }
}
