package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletSegmentDisplay4x7Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Segments")
    public @ActionOutput(name = "segments", type="short[]")
           @ActionOutput(name = "brightness", type="short")
           @ActionOutput(name = "colon", type="boolean")
           Map<String, Object> getSegments(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletSegmentDisplay4x7.Segments value = ((BrickletSegmentDisplay4x7)this.handler.getDevice()).getSegments();
        result.put("segments", value.segments);
        result.put("brightness", value.brightness);
        result.put("colon", value.colon);
        return result;
    }

    public static Map<String, Object> getSegments(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletSegmentDisplay4x7Actions) {
            return ((BrickletSegmentDisplay4x7Actions) actions).getSegments();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSegmentDisplay4x7Actions class.");
        }
    }

    @RuleAction(label = "Start Counter")
    public void startCounter(
            @ActionInput(name = "valueFrom") short valueFrom,
            @ActionInput(name = "valueTo") short valueTo,
            @ActionInput(name = "increment") short increment,
            @ActionInput(name = "length") long length) throws TinkerforgeException {
        ((BrickletSegmentDisplay4x7)this.handler.getDevice()).startCounter(valueFrom, valueTo, increment, length);
    }

    public static void startCounter(@Nullable ThingActions actions, short valueFrom, short valueTo, short increment, long length) throws TinkerforgeException {
        if (actions instanceof BrickletSegmentDisplay4x7Actions) {
            ((BrickletSegmentDisplay4x7Actions) actions).startCounter(valueFrom, valueTo, increment, length);
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSegmentDisplay4x7Actions class.");
        }
    }

    @RuleAction(label = "Get Counter Value")
    public @ActionOutput(name = "value", type="int")
           Map<String, Object> getCounterValue(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletSegmentDisplay4x7)this.handler.getDevice()).getCounterValue();
        result.put("value", value);
        return result;
    }

    public static Map<String, Object> getCounterValue(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletSegmentDisplay4x7Actions) {
            return ((BrickletSegmentDisplay4x7Actions) actions).getCounterValue();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSegmentDisplay4x7Actions class.");
        }
    }
}
