package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletSoundPressureLevelActions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Decibel")
    public @ActionOutput(name = "decibel", type="int")
           Map<String, Object> getDecibel(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletSoundPressureLevel)this.handler.getDevice()).getDecibel();
        result.put("decibel", value);
        return result;
    }

    public static Map<String, Object> getDecibel(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletSoundPressureLevelActions) {
            return ((BrickletSoundPressureLevelActions) actions).getDecibel();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSoundPressureLevelActions class.");
        }
    }

    @RuleAction(label = "Get Spectrum")
    public @ActionOutput(name = "spectrum", type="int[]")
           Map<String, Object> getSpectrum(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int[] value = ((BrickletSoundPressureLevel)this.handler.getDevice()).getSpectrum();
        result.put("spectrum", value);
        return result;
    }

    public static Map<String, Object> getSpectrum(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletSoundPressureLevelActions) {
            return ((BrickletSoundPressureLevelActions) actions).getSpectrum();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSoundPressureLevelActions class.");
        }
    }

    @RuleAction(label = "Get Configuration")
    public @ActionOutput(name = "fftSize", type="int")
           @ActionOutput(name = "weighting", type="int")
           Map<String, Object> getConfiguration(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        BrickletSoundPressureLevel.Configuration value = ((BrickletSoundPressureLevel)this.handler.getDevice()).getConfiguration();
        result.put("fftSize", value.fftSize);
        result.put("weighting", value.weighting);
        return result;
    }

    public static Map<String, Object> getConfiguration(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletSoundPressureLevelActions) {
            return ((BrickletSoundPressureLevelActions) actions).getConfiguration();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletSoundPressureLevelActions class.");
        }
    }
}
