package com.tinkerforge;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.smarthome.binding.tinkerforge.internal.handler.DeviceHandler;
import org.eclipse.smarthome.core.thing.binding.ThingActions;
import org.eclipse.smarthome.core.thing.binding.ThingActionsScope;
import org.eclipse.smarthome.core.thing.binding.ThingHandler;
import org.openhab.core.automation.annotation.ActionInput;
import org.openhab.core.automation.annotation.ActionOutput;
import org.openhab.core.automation.annotation.RuleAction;

import java.util.Map;
import java.util.HashMap;

@ThingActionsScope(name = "tinkerforge")
@NonNullByDefault
public class BrickletTemperatureIRV2Actions implements ThingActions {

    private @Nullable DeviceHandler handler;

    @Override
    public void setThingHandler(@Nullable ThingHandler handler) { this.handler = (DeviceHandler) handler; }

    @Override
    public @Nullable ThingHandler getThingHandler() { return handler; }

        @RuleAction(label = "Get Ambient Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getAmbientTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletTemperatureIRV2)this.handler.getDevice()).getAmbientTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getAmbientTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletTemperatureIRV2Actions) {
            return ((BrickletTemperatureIRV2Actions) actions).getAmbientTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletTemperatureIRV2Actions class.");
        }
    }

    @RuleAction(label = "Get Object Temperature")
    public @ActionOutput(name = "temperature", type="int")
           Map<String, Object> getObjectTemperature(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletTemperatureIRV2)this.handler.getDevice()).getObjectTemperature();
        result.put("temperature", value);
        return result;
    }

    public static Map<String, Object> getObjectTemperature(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletTemperatureIRV2Actions) {
            return ((BrickletTemperatureIRV2Actions) actions).getObjectTemperature();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletTemperatureIRV2Actions class.");
        }
    }

    @RuleAction(label = "Get Emissivity")
    public @ActionOutput(name = "emissivity", type="int")
           Map<String, Object> getEmissivity(
            ) throws TinkerforgeException {
        Map<String, Object> result = new HashMap<>();
        int value = ((BrickletTemperatureIRV2)this.handler.getDevice()).getEmissivity();
        result.put("emissivity", value);
        return result;
    }

    public static Map<String, Object> getEmissivity(@Nullable ThingActions actions) throws TinkerforgeException {
        if (actions instanceof BrickletTemperatureIRV2Actions) {
            return ((BrickletTemperatureIRV2Actions) actions).getEmissivity();
        } else {
            throw new IllegalArgumentException("Instance is not an BrickletTemperatureIRV2Actions class.");
        }
    }
}
